@@ -3,8 +3,9 @@ BEGIN {
   $Constant::Export::Lazy::AUTHORITY = 'cpan:AVAR';
 }
 {
-  $Constant::Export::Lazy::VERSION = '0.11';
+  $Constant::Export::Lazy::VERSION = '0.12';
 }
+use 5.006;
 use strict;
 use warnings;
 
@@ -181,7 +182,7 @@ BEGIN {
   $Constant::Export::Lazy::Ctx::AUTHORITY = 'cpan:AVAR';
 }
 {
-  $Constant::Export::Lazy::Ctx::VERSION = '0.11';
+  $Constant::Export::Lazy::Ctx::VERSION = '0.12';
 }
 use strict;
 use warnings;
@@ -943,5 +944,12 @@ there's no stash reference defined.
 
 Ævar Arnfjörð Bjarmason <avar@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by Ævar Arnfjörð Bjarmason <avar@cpan.org>
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
